Name:           opentype-sanitizer
Version:        9.1.0
Release:    1%{?dist}
Summary:        Parses and serializes OpenType/WOFF/WOFF2 font files

License:        BSD-3-Clause
URL:            https://github.com/khaledhosny/ots
Source0:        ots-%{version}-filtered.tar.xz
Source1:        get-source.py
Source2:        ots-%{version}-excluded-font-checksums.txt

ExcludeArch:    %{ix86}

BuildRequires:  meson
BuildRequires:  ninja-build
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libwoff2dec)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(gtest)

%global common_description %{expand:
The OpenType Sanitizer (OTS) parses and serializes OpenType files (OTF, TTF)
and WOFF and WOFF2 font files, validating them and sanitizing them as it goes.

The C library is integrated into Chromium and Firefox, and also simple command
line tools to check files offline in a Terminal.

The CSS font-face property is great for web typography. Having to use images in
order to get the correct typeface is a great sadness; one should be able to use
vectors.

However, on many platforms the system-level TrueType font renderers have never
been part of the attack surface before, and putting them on the front line is a
scary proposition... Especially on platforms like Windows, where it’s a
closed-source blob running with high privilege.}

%description %{common_description}


%prep
%autosetup -n ots-%{version} -p1
rm -rf third_party
sed -r -i "/$(tr '\n' '|' < '%{SOURCE2}' | sed -r 's@\|+$@@')/d" \
    tests/meson.build


%build
%meson -Dcpp_std=c++14
%meson_build


%install
%meson_install


%check
%meson_test


%files
%license LICENSE
%doc README.md
%doc docs/*.md

%{_bindir}/ots-idempotent
%{_bindir}/ots-perf
%{_bindir}/ots-sanitize
%{_bindir}/ots-side-by-side
%{_bindir}/ots-validator-checker

%{_mandir}/man1/ots-idempotent.1*
%{_mandir}/man1/ots-perf.1*
%{_mandir}/man1/ots-sanitize.1*
%{_mandir}/man1/ots-side-by-side.1*
%{_mandir}/man1/ots-validator-checker.1*


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.1.0-1
- initial build
